@@ -131,13 +131,13 @@ T18:;
 	base[3]= VV[10];
 	base[4]= Ct;
 	vs_top=(vs_base=base+2)+3;
-	(void) (*Lnk32)();
+	Lmake_list();
 	vs_top=sup;
 	V43= vs_base[0];
 	V44= (VFUN_NARGS=2,(*(LnkLI31))((V34),V43));
 	V34= (*(LnkLI30))(/* INLINE-ARGS */V44,(V32));
 	princ_str("\n	{object ",VV[11]);
-	(void)((*(LnkLI33))((V37)));
+	(void)((*(LnkLI32))((V37)));
 	princ_char(59,VV[11]);
 	{register object V45;
 	object V46;
@@ -149,9 +149,9 @@ T38:;
 	goto T34;
 T39:;
 	princ_str("\n	object ",VV[11]);
-	(void)((*(LnkLI33))((V46)));
+	(void)((*(LnkLI32))((V46)));
 	princ_str("= ",VV[11]);
-	(void)((*(LnkLI33))(car((V34))));
+	(void)((*(LnkLI32))(car((V34))));
 	princ_char(59,VV[11]);
 	{object V47;
 	V47= car((V34));
@@ -163,7 +163,7 @@ T34:;
 	if((symbol_value(VV[12]))==Cnil){
 	goto T60;}
 	princ_str("\n	if(endp(",VV[11]);
-	(void)((*(LnkLI33))(car((V38))));
+	(void)((*(LnkLI32))(car((V38))));
 	princ_char(41,VV[11]);
 	{register object V48;
 	object V49;
@@ -175,7 +175,7 @@ T70:;
 	goto T66;
 T71:;
 	princ_str("||endp(",VV[11]);
-	(void)((*(LnkLI33))((V49)));
+	(void)((*(LnkLI32))((V49)));
 	princ_char(41,VV[11]);
 	V48= cdr((V48));
 	V49= car((V48));
@@ -185,7 +185,7 @@ T66:;
 	goto T58;
 T60:;
 	princ_str("\n	if(",VV[11]);
-	(void)((*(LnkLI33))(car((V38))));
+	(void)((*(LnkLI32))(car((V38))));
 	princ_str("==Cnil",VV[11]);
 	{register object V50;
 	object V51;
@@ -197,7 +197,7 @@ T93:;
 	goto T89;
 T94:;
 	princ_str("||",VV[11]);
-	(void)((*(LnkLI33))((V51)));
+	(void)((*(LnkLI32))((V51)));
 	princ_str("==Cnil",VV[11]);
 	V50= cdr((V50));
 	V51= car((V50));
@@ -205,17 +205,17 @@ T94:;
 T89:;
 	princ_str("){",VV[11]);
 T58:;
-	(void)((VFUN_NARGS=2,(*(LnkLI34))(Cnil,VV[13])));
+	(void)((VFUN_NARGS=2,(*(LnkLI33))(Cnil,VV[13])));
 	princ_char(125,VV[11]);
 	princ_str("\n	",VV[11]);
-	(void)((*(LnkLI33))((V36)));
+	(void)((*(LnkLI32))((V36)));
 	princ_char(61,VV[11]);
-	(void)((*(LnkLI33))((V37)));
+	(void)((*(LnkLI32))((V37)));
 	princ_str("=MMcons(Cnil,Cnil);",VV[11]);
 	if((cdr((V35)))==Cnil){
 	goto T117;}
 	princ_str("\nT",VV[11]);
-	(void)((*(LnkLI33))(car((V35))));
+	(void)((*(LnkLI32))(car((V35))));
 	princ_str(":;",VV[11]);
 T117:;
 	bds_bind(VV[14],list(2,VV[15],cadr((V37))));
@@ -253,14 +253,14 @@ T135:;
 	V57=MMcdr(V57)=MMcons(Cnil,Cnil);
 	goto T135;}
 T129:;
-	(void)((VFUN_NARGS=3,(*(LnkLI35))((V32),V52,(V39))));
+	(void)((VFUN_NARGS=3,(*(LnkLI34))((V32),V52,(V39))));
 	if((cdr((VV[16]->s.s_dbind)))==Cnil){
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 	goto T123;}
 	princ_str("\nT",VV[11]);
-	(void)((*(LnkLI33))(car((VV[16]->s.s_dbind))));
+	(void)((*(LnkLI32))(car((VV[16]->s.s_dbind))));
 	princ_str(":;",VV[11]);
 	bds_unwind1;
 	bds_unwind1;
@@ -269,9 +269,9 @@ T123:;
 	if((symbol_value(VV[12]))==Cnil){
 	goto T144;}
 	princ_str("\n	if(endp(",VV[11]);
-	(void)((*(LnkLI33))(car((V38))));
+	(void)((*(LnkLI32))(car((V38))));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))(car((V38))));
+	(void)((*(LnkLI32))(car((V38))));
 	princ_str("))",VV[11]);
 	{register object V60;
 	object V61;
@@ -283,9 +283,9 @@ T156:;
 	goto T152;
 T157:;
 	princ_str("||endp(",VV[11]);
-	(void)((*(LnkLI33))((V61)));
+	(void)((*(LnkLI32))((V61)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V61)));
+	(void)((*(LnkLI32))((V61)));
 	princ_str("))",VV[11]);
 	V60= cdr((V60));
 	V61= car((V60));
@@ -295,9 +295,9 @@ T152:;
 	goto T142;
 T144:;
 	princ_str("\n	if((",VV[11]);
-	(void)((*(LnkLI33))(car((V38))));
+	(void)((*(LnkLI32))(car((V38))));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))(car((V38))));
+	(void)((*(LnkLI32))(car((V38))));
 	princ_str("))==Cnil",VV[11]);
 	{register object V62;
 	object V63;
@@ -309,9 +309,9 @@ T183:;
 	goto T179;
 T184:;
 	princ_str("||(",VV[11]);
-	(void)((*(LnkLI33))((V63)));
+	(void)((*(LnkLI32))((V63)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V63)));
+	(void)((*(LnkLI32))((V63)));
 	princ_str("))==Cnil",VV[11]);
 	V62= cdr((V62));
 	V63= car((V62));
@@ -319,21 +319,21 @@ T184:;
 T179:;
 	princ_str("){",VV[11]);
 T142:;
-	(void)((VFUN_NARGS=2,(*(LnkLI34))((V36),VV[13])));
+	(void)((VFUN_NARGS=2,(*(LnkLI33))((V36),VV[13])));
 	princ_char(125,VV[11]);
 	princ_str("\n	",VV[11]);
-	(void)((*(LnkLI33))((V37)));
+	(void)((*(LnkLI32))((V37)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V37)));
+	(void)((*(LnkLI32))((V37)));
 	princ_str(")=MMcons(Cnil,Cnil);",VV[11]);
 	princ_str("\n	",VV[11]);
 	if(type_of((V35))!=t_cons)FEwrong_type_argument(Scons,(V35));
 	((V35))->c.c_cdr = Ct;
 	princ_str("goto T",VV[11]);
-	(void)((*(LnkLI33))(car((V35))));
+	(void)((*(LnkLI32))(car((V35))));
 	princ_char(59,VV[11]);
 	princ_char(125,VV[11]);
-	{object V64 = (*(LnkLI36))();
+	{object V64 = (*(LnkLI35))();
 	bds_unwind1;
 	bds_unwind1;
 	VMR8(V64)}}
@@ -376,7 +376,7 @@ T219:;
 	base[3]= VV[10];
 	base[4]= Ct;
 	vs_top=(vs_base=base+2)+3;
-	(void) (*Lnk32)();
+	Lmake_list();
 	vs_top=sup;
 	V78= vs_base[0];
 	V79= (VFUN_NARGS=2,(*(LnkLI31))((V70),V78));
@@ -393,9 +393,9 @@ T239:;
 	goto T235;
 T240:;
 	princ_str("\n	object ",VV[11]);
-	(void)((*(LnkLI33))((V81)));
+	(void)((*(LnkLI32))((V81)));
 	princ_str("= ",VV[11]);
-	(void)((*(LnkLI33))(car((V70))));
+	(void)((*(LnkLI32))(car((V70))));
 	princ_char(59,VV[11]);
 	{object V82;
 	V82= car((V70));
@@ -407,7 +407,7 @@ T235:;
 	if((symbol_value(VV[12]))==Cnil){
 	goto T261;}
 	princ_str("\n	if(endp(",VV[11]);
-	(void)((*(LnkLI33))(car((V73))));
+	(void)((*(LnkLI32))(car((V73))));
 	princ_char(41,VV[11]);
 	{register object V83;
 	object V84;
@@ -419,7 +419,7 @@ T271:;
 	goto T267;
 T272:;
 	princ_str("||endp(",VV[11]);
-	(void)((*(LnkLI33))((V84)));
+	(void)((*(LnkLI32))((V84)));
 	princ_char(41,VV[11]);
 	V83= cdr((V83));
 	V84= car((V83));
@@ -429,7 +429,7 @@ T267:;
 	goto T259;
 T261:;
 	princ_str("\n	if(",VV[11]);
-	(void)((*(LnkLI33))(car((V73))));
+	(void)((*(LnkLI32))(car((V73))));
 	princ_str("==Cnil",VV[11]);
 	{register object V85;
 	object V86;
@@ -441,7 +441,7 @@ T294:;
 	goto T290;
 T295:;
 	princ_str("||",VV[11]);
-	(void)((*(LnkLI33))((V86)));
+	(void)((*(LnkLI32))((V86)));
 	princ_str("==Cnil",VV[11]);
 	V85= cdr((V85));
 	V86= car((V85));
@@ -449,12 +449,12 @@ T295:;
 T290:;
 	princ_str("){",VV[11]);
 T259:;
-	(void)((VFUN_NARGS=2,(*(LnkLI34))(Cnil,VV[13])));
+	(void)((VFUN_NARGS=2,(*(LnkLI33))(Cnil,VV[13])));
 	princ_char(125,VV[11]);
 	if((cdr((V71)))==Cnil){
 	goto T312;}
 	princ_str("\nT",VV[11]);
-	(void)((*(LnkLI33))(car((V71))));
+	(void)((*(LnkLI32))(car((V71))));
 	princ_str(":;",VV[11]);
 T312:;
 	bds_bind(VV[14],VV[20]);
@@ -492,14 +492,14 @@ T329:;
 	V92=MMcdr(V92)=MMcons(Cnil,Cnil);
 	goto T329;}
 T323:;
-	(void)((VFUN_NARGS=3,(*(LnkLI35))((V68),V87,(V74))));
+	(void)((VFUN_NARGS=3,(*(LnkLI34))((V68),V87,(V74))));
 	if((cdr((VV[16]->s.s_dbind)))==Cnil){
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 	goto T318;}
 	princ_str("\nT",VV[11]);
-	(void)((*(LnkLI33))(car((VV[16]->s.s_dbind))));
+	(void)((*(LnkLI32))(car((VV[16]->s.s_dbind))));
 	princ_str(":;",VV[11]);
 	bds_unwind1;
 	bds_unwind1;
@@ -508,9 +508,9 @@ T318:;
 	if((symbol_value(VV[12]))==Cnil){
 	goto T338;}
 	princ_str("\n	if(endp(",VV[11]);
-	(void)((*(LnkLI33))(car((V73))));
+	(void)((*(LnkLI32))(car((V73))));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))(car((V73))));
+	(void)((*(LnkLI32))(car((V73))));
 	princ_str("))",VV[11]);
 	{register object V95;
 	object V96;
@@ -522,9 +522,9 @@ T350:;
 	goto T346;
 T351:;
 	princ_str("||endp(",VV[11]);
-	(void)((*(LnkLI33))((V96)));
+	(void)((*(LnkLI32))((V96)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V96)));
+	(void)((*(LnkLI32))((V96)));
 	princ_str("))",VV[11]);
 	V95= cdr((V95));
 	V96= car((V95));
@@ -534,9 +534,9 @@ T346:;
 	goto T336;
 T338:;
 	princ_str("\n	if((",VV[11]);
-	(void)((*(LnkLI33))(car((V73))));
+	(void)((*(LnkLI32))(car((V73))));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))(car((V73))));
+	(void)((*(LnkLI32))(car((V73))));
 	princ_str("))==Cnil",VV[11]);
 	{register object V97;
 	object V98;
@@ -548,9 +548,9 @@ T377:;
 	goto T373;
 T378:;
 	princ_str("||(",VV[11]);
-	(void)((*(LnkLI33))((V98)));
+	(void)((*(LnkLI32))((V98)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V98)));
+	(void)((*(LnkLI32))((V98)));
 	princ_str("))==Cnil",VV[11]);
 	V97= cdr((V97));
 	V98= car((V97));
@@ -558,16 +558,16 @@ T378:;
 T373:;
 	princ_str("){",VV[11]);
 T336:;
-	(void)((VFUN_NARGS=2,(*(LnkLI34))((V72),VV[13])));
+	(void)((VFUN_NARGS=2,(*(LnkLI33))((V72),VV[13])));
 	princ_char(125,VV[11]);
 	princ_str("\n	",VV[11]);
 	if(type_of((V71))!=t_cons)FEwrong_type_argument(Scons,(V71));
 	((V71))->c.c_cdr = Ct;
 	princ_str("goto T",VV[11]);
-	(void)((*(LnkLI33))(car((V71))));
+	(void)((*(LnkLI32))(car((V71))));
 	princ_char(59,VV[11]);
 	princ_char(125,VV[11]);
-	{object V99 = (*(LnkLI36))();
+	{object V99 = (*(LnkLI35))();
 	bds_unwind1;
 	bds_unwind1;
 	VMR9(V99)}}
@@ -613,13 +613,13 @@ T410:;
 	base[3]= VV[10];
 	base[4]= Ct;
 	vs_top=(vs_base=base+2)+3;
-	(void) (*Lnk32)();
+	Lmake_list();
 	vs_top=sup;
 	V114= vs_base[0];
 	V115= (VFUN_NARGS=2,(*(LnkLI31))((V105),V114));
 	V105= (*(LnkLI30))(/* INLINE-ARGS */V115,(V103));
 	princ_str("\n	{object ",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_char(59,VV[11]);
 	{register object V116;
 	object V117;
@@ -631,9 +631,9 @@ T430:;
 	goto T426;
 T431:;
 	princ_str("\n	object ",VV[11]);
-	(void)((*(LnkLI33))((V117)));
+	(void)((*(LnkLI32))((V117)));
 	princ_str("= ",VV[11]);
-	(void)((*(LnkLI33))(car((V105))));
+	(void)((*(LnkLI32))(car((V105))));
 	princ_char(59,VV[11]);
 	{object V118;
 	V118= car((V105));
@@ -645,7 +645,7 @@ T426:;
 	if((symbol_value(VV[12]))==Cnil){
 	goto T452;}
 	princ_str("\n	if(endp(",VV[11]);
-	(void)((*(LnkLI33))(car((V109))));
+	(void)((*(LnkLI32))(car((V109))));
 	princ_char(41,VV[11]);
 	{register object V119;
 	object V120;
@@ -657,7 +657,7 @@ T462:;
 	goto T458;
 T463:;
 	princ_str("||endp(",VV[11]);
-	(void)((*(LnkLI33))((V120)));
+	(void)((*(LnkLI32))((V120)));
 	princ_char(41,VV[11]);
 	V119= cdr((V119));
 	V120= car((V119));
@@ -667,7 +667,7 @@ T458:;
 	goto T450;
 T452:;
 	princ_str("\n	if(",VV[11]);
-	(void)((*(LnkLI33))(car((V109))));
+	(void)((*(LnkLI32))(car((V109))));
 	princ_str("==Cnil",VV[11]);
 	{register object V121;
 	object V122;
@@ -679,7 +679,7 @@ T485:;
 	goto T481;
 T486:;
 	princ_str("||",VV[11]);
-	(void)((*(LnkLI33))((V122)));
+	(void)((*(LnkLI32))((V122)));
 	princ_str("==Cnil",VV[11]);
 	V121= cdr((V121));
 	V122= car((V121));
@@ -687,17 +687,17 @@ T486:;
 T481:;
 	princ_str("){",VV[11]);
 T450:;
-	(void)((VFUN_NARGS=2,(*(LnkLI34))(Cnil,VV[13])));
+	(void)((VFUN_NARGS=2,(*(LnkLI33))(Cnil,VV[13])));
 	princ_char(125,VV[11]);
 	princ_str("\n	",VV[11]);
-	(void)((*(LnkLI33))((V107)));
+	(void)((*(LnkLI32))((V107)));
 	princ_char(61,VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str("=MMcons(Cnil,Cnil);",VV[11]);
 	if((cdr((V106)))==Cnil){
 	goto T509;}
 	princ_str("\nT",VV[11]);
-	(void)((*(LnkLI33))(car((V106))));
+	(void)((*(LnkLI32))(car((V106))));
 	princ_str(":;",VV[11]);
 T509:;
 	bds_bind(VV[14],list(2,VV[21],cadr((V108))));
@@ -735,14 +735,14 @@ T527:;
 	V128=MMcdr(V128)=MMcons(Cnil,Cnil);
 	goto T527;}
 T521:;
-	(void)((VFUN_NARGS=3,(*(LnkLI35))((V103),V123,(V110))));
+	(void)((VFUN_NARGS=3,(*(LnkLI34))((V103),V123,(V110))));
 	if((cdr((VV[16]->s.s_dbind)))==Cnil){
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 	goto T515;}
 	princ_str("\nT",VV[11]);
-	(void)((*(LnkLI33))(car((VV[16]->s.s_dbind))));
+	(void)((*(LnkLI32))(car((VV[16]->s.s_dbind))));
 	princ_str(":;",VV[11]);
 	bds_unwind1;
 	bds_unwind1;
@@ -751,16 +751,16 @@ T515:;
 	if((symbol_value(VV[12]))==Cnil){
 	goto T536;}
 	princ_str("\n	while(!endp(MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str(")))",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str(");",VV[11]);
 	princ_str("\n	if(endp(",VV[11]);
-	(void)((*(LnkLI33))(car((V109))));
+	(void)((*(LnkLI32))(car((V109))));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))(car((V109))));
+	(void)((*(LnkLI32))(car((V109))));
 	princ_str("))",VV[11]);
 	{register object V131;
 	object V132;
@@ -772,9 +772,9 @@ T556:;
 	goto T552;
 T557:;
 	princ_str("||endp(",VV[11]);
-	(void)((*(LnkLI33))((V132)));
+	(void)((*(LnkLI32))((V132)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V132)));
+	(void)((*(LnkLI32))((V132)));
 	princ_str("))",VV[11]);
 	V131= cdr((V131));
 	V132= car((V131));
@@ -784,16 +784,16 @@ T552:;
 	goto T534;
 T536:;
 	princ_str("\n	while(MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str(")!=Cnil)",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V108)));
+	(void)((*(LnkLI32))((V108)));
 	princ_str(");",VV[11]);
 	princ_str("\n	if((",VV[11]);
-	(void)((*(LnkLI33))(car((V109))));
+	(void)((*(LnkLI32))(car((V109))));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))(car((V109))));
+	(void)((*(LnkLI32))(car((V109))));
 	princ_str("))==Cnil",VV[11]);
 	{register object V133;
 	object V134;
@@ -805,9 +805,9 @@ T591:;
 	goto T587;
 T592:;
 	princ_str("||(",VV[11]);
-	(void)((*(LnkLI33))((V134)));
+	(void)((*(LnkLI32))((V134)));
 	princ_str("=MMcdr(",VV[11]);
-	(void)((*(LnkLI33))((V134)));
+	(void)((*(LnkLI32))((V134)));
 	princ_str("))==Cnil",VV[11]);
 	V133= cdr((V133));
 	V134= car((V133));
@@ -816,20 +816,20 @@ T587:;
 	princ_str("){",VV[11]);
 T534:;
 	princ_str("\n	",VV[11]);
-	(void)((*(LnkLI33))((V107)));
+	(void)((*(LnkLI32))((V107)));
 	princ_char(61,VV[11]);
-	(void)((*(LnkLI33))((V107)));
+	(void)((*(LnkLI32))((V107)));
 	princ_str("->c.c_cdr;",VV[11]);
-	(void)((VFUN_NARGS=2,(*(LnkLI34))((V107),VV[13])));
+	(void)((VFUN_NARGS=2,(*(LnkLI33))((V107),VV[13])));
 	princ_char(125,VV[11]);
 	princ_str("\n	",VV[11]);
 	if(type_of((V106))!=t_cons)FEwrong_type_argument(Scons,(V106));
 	((V106))->c.c_cdr = Ct;
 	princ_str("goto T",VV[11]);
-	(void)((*(LnkLI33))(car((V106))));
+	(void)((*(LnkLI32))(car((V106))));
 	princ_char(59,VV[11]);
 	princ_char(125,VV[11]);
-	{object V135 = (*(LnkLI36))();
+	{object V135 = (*(LnkLI35))();
 	bds_unwind1;
 	bds_unwind1;
 	VMR10(V135)}}
@@ -859,14 +859,14 @@ T631:;
 	goto T637;}
 	if(!((car((V143)))==(VV[22]))){
 	goto T637;}
-	if(((*(LnkLI37))(cadr((V143)),(V141)))==Cnil){
+	if(((*(LnkLI36))(cadr((V143)),(V141)))==Cnil){
 	goto T637;}
 	{register object V145;
 	V145= list(2,VV[7],(*(LnkLI28))());
 	princ_str("\n	",VV[11]);
-	(void)((*(LnkLI33))((V145)));
+	(void)((*(LnkLI32))((V145)));
 	princ_str("= ",VV[11]);
-	(void)((*(LnkLI33))((V143)));
+	(void)((*(LnkLI32))((V143)));
 	princ_char(59,VV[11]);
 	V140= make_cons((V145),(V140));
 	goto T635;}
@@ -877,12 +877,11 @@ T635:;
 	V143= car((V142));
 	goto T630;}}
 }
-static object  LnkTLI37(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[37],&LnkLI37,2,ap);} /* ARGS-INFO-CHANGED-VARS */
-static object  LnkTLI36(){return call_proc0(VV[36],&LnkLI36);} /* CLOSE-INLINE-BLOCKS */
-static object  LnkTLI35(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[35],&LnkLI35,ap);} /* C2FUNCALL */
-static object  LnkTLI34(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[34],&LnkLI34,ap);} /* UNWIND-EXIT */
-static object  LnkTLI33(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[33],&LnkLI33,1,ap);} /* WT1 */
-static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* MAKE-LIST */
+static object  LnkTLI36(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[36],&LnkLI36,2,ap);} /* ARGS-INFO-CHANGED-VARS */
+static object  LnkTLI35(){return call_proc0(VV[35],&LnkLI35);} /* CLOSE-INLINE-BLOCKS */
+static object  LnkTLI34(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[34],&LnkLI34,ap);} /* C2FUNCALL */
+static object  LnkTLI33(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[33],&LnkLI33,ap);} /* UNWIND-EXIT */
+static object  LnkTLI32(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[32],&LnkLI32,1,ap);} /* WT1 */
 static object  LnkTLI31(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[31],&LnkLI31,ap);} /* INLINE-ARGS */
 static object  LnkTLI30(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[30],&LnkLI30,2,ap);} /* PUSH-CHANGED-VARS */
 static object  LnkTLI29(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[29],&LnkLI29,1,ap);} /* SAVE-FUNOB */
