@@ -571,9 +571,14 @@
 		  pathname option ))
        (pp option no_quote)
        (setq l (cdr l))
+       (print (car l))
        (cond ((and (keywordp (car l))
 		   (not (eq option :configure))
-		   (not (eq option :config)))
+		   (not (eq option :config))
+		   (not (eq option :itemconfig))
+		   (not (eq option :cget))
+		   (not (eq option :postscript))
+			)
 	      (pp (car l) no_quote)
 	      (setq l (cdr l))))
        (print-arglist tk-command l)
@@ -793,6 +798,10 @@
 (def-control tk-dialog :print-name "tk_dialog")
 (def-control get_tag_range)
 
+(def-control lsearch)
+(def-control lindex)
+
+
 (defun tk-wait-til-exists (win)
   (tk-do (tk-conc "if ([winfo exists " win " ]) { } else {tkwait visibility " win "}")))
 
