@@ -23,6 +23,15 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 	include.h
 */
 
+
+/* whether to use prototypes or not */
+#ifdef __STDC__
+#define P__(x) x
+#else
+#define P__(x)
+#endif
+
+
 #include "options.h"
 #include "config.h"
 
@@ -59,6 +68,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include "../h/notcomp.h"
 #include "../h/funlink.h"
 #include "../h/att_ext.h"
+#include "../h/new_decl.h"
 #include "compbas2.h"
 #include "compat.h"
 
