@@ -66,10 +66,7 @@
 
 
 
-/* the va_list is not aligned sometimes
-   maybe you can just realign and not copy...dont know.. */
 
-#define MUST_COPY_VA_LIST
 
 #ifdef IN_UNIXFSYS
 #undef ATT
