@@ -12,12 +12,8 @@ proper "License Agreement for Kyoto Common LISP" with SIGLISP.
 */
 
 
-object *lex_env;
+EXTER object *lex_env;
 
-object Sfunction;
-object Smacro;
-object Stag;
-object Sblock;
 
 
 /*
