@@ -23,6 +23,15 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
 
+/* whether to use prototypes or not */
+#ifdef __STDC__
+#define P__(x) x
+#else
+#define P__(x)
+#endif
+
+
+
 #ifdef __GNUC__
 #ifndef alloca
 #define alloca __builtin_alloca
