@@ -21,12 +21,15 @@
 #define	IEEEFLOAT
 
 #undef SET_REAL_MAXPAGE
-#define SET_REAL_MAXPAGE \
-	real_maxpage= ulimit(3)/PAGESIZE; \
-	if (real_maxpage > MAXPAGE) \
-		real_maxpage = MAXPAGE;
 
-#define N_DATADDR(header) 
+#define SET_REAL_MAXPAGE \
+        real_maxpage= ulimit(3)/PAGESIZE; \
+        if ((real_maxpage > MAXPAGE) || (ulimit(3) < 0)) \
+                real_maxpage = MAXPAGE;
+
+
+
+#define N_DATADDR(header)
 #define DATA_BEGIN (char *)header.a_dbase
 
 #define PAGEWIDTH 12
