@@ -64,10 +64,11 @@ DEFUNO("AREF", object, fLaref, LISP, 1, ARRAY_RANK_LIMIT,
   int i1;
   va_list ap;
   if (type_of(x) == t_array)
-    {int m,k ;
+    {int m ;
+     unsigned int k;
      int rank = n - 1; 
      if (x->a.a_rank != rank)
-       FEerror(" ~a has wrong rank",x);
+       FEerror(" ~a has wrong rank",1,x);
      if (rank == 1) return fSaref1(x,i);
      if (rank == 0) return fSaref1(x,0);
      va_start(ap);
@@ -78,7 +79,7 @@ DEFUNO("AREF", object, fLaref, LISP, 1, ARRAY_RANK_LIMIT,
      rank-- ;
      while(1) 
        {
-	 if (k >= x->a.a_dims[m])
+	 if ( k >= x->a.a_dims[m])
 	   FEerror("Index ~a to array is too large",1,make_fixnum (m));
 	 i1 += k;
 	 m ++;
@@ -109,11 +110,12 @@ fScheck_bounds_bounds(x, i)
   switch (type_of(x)) {
   case t_array:
   case t_vector:
+  case t_bitvector:
   case t_string:
     if ((unsigned int) i >= x->a.a_dim)
-    FEerror("Array ref out of bounds ~a ~a", 2, x, make_fixnum(i));
+    FEerror("Array index ~a out of bounds for ~a", 2,  make_fixnum(i),x);
   default:
-    FEerror("not an array");
+    FEerror("not an array",0);
   }
 }
 
@@ -144,7 +146,7 @@ DEFUN("AREF1", object, fSaref1, SI, 2, 2,
   case t_array:
   case t_vector:
   case t_bitvector:
-    if (x->v.v_dim <= i)
+    if (x->v.v_dim <= (unsigned int)i)
       i = fScheck_bounds_bounds(x, i);
     switch (x->v.v_elttype) {
     case aet_object:
@@ -152,7 +154,7 @@ DEFUN("AREF1", object, fSaref1, SI, 2, 2,
     case aet_ch:
       return code_char(x->st.st_self[i]);
     case aet_bit:
-      i += x->bv.bv_offset;
+      i += BV_OFFSET(x);
       return make_fixnum(BITREF(x, i));
     case aet_fix:
       return make_fixnum(x->fixa.fixa_self[i]);
@@ -170,14 +172,14 @@ DEFUN("AREF1", object, fSaref1, SI, 2, 2,
       return make_fixnum(USHORT(x, i));
 
     default:
-      FEerror("unknown array type");
+      FEerror("unknown array type",0);
     }
   case t_string:
     if (x->v.v_dim <= i)
       i = fScheck_bounds_bounds(x, i);
     return code_char(x->st.st_self[i]);
   default:
-    FEerror("not an array");
+    FEerror("not an array",0);
 
     ;
   }
@@ -204,7 +206,7 @@ DEFUN("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,"")
       x->st.st_self[i] = char_code(val);
       break;
     case aet_bit:
-      i += x->bv.bv_offset;
+      i +=  BV_OFFSET(x);
     AGAIN_BIT: 
       ASSURE_TYPE(val,t_fixnum);
       {int v = Mfix(val);
@@ -242,7 +244,7 @@ DEFUN("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,"")
       USHORT(x, i) = Mfix(val);
       break;
     default:
-      FEerror("unknown array type");
+      FEerror("unknown array type",0);
     }
     break;
   case t_string:
@@ -268,10 +270,11 @@ DEFUNO("ASET", object, fSaset, SI, 1, ARG_LIMIT, NONE, OO,
   int i;
   va_list ap;
   if (type_of(x) == t_array)
-    {int m,k ;
+    {int m ;
+     unsigned int k;
      int rank = n - 2; 
      if (x->a.a_rank != rank)
-       FEerror(" ~a has wrong rank",x);
+       FEerror(" ~a has wrong rank",1,x);
      if (rank == 0) return fSaset1(x,0,ii);
      ASSURE_TYPE(ii,t_fixnum);
      i = fix(ii);
@@ -286,7 +289,8 @@ DEFUNO("ASET", object, fSaset, SI, 1, ARG_LIMIT, NONE, OO,
      while(1) 
        {
 	 if (k >= x->a.a_dims[m])
-	   FEerror("Index ~a to array is too large",1,make_fixnum (m));
+	   FEerror("Index number  ~a: ~a to array is out of bounds",
+		   2,make_fixnum (m),make_fixnum(k));
 	 i1 += k;
 	 if (m < rank)
 	   {object u;
@@ -351,14 +355,18 @@ int n;int elt_type;object staticp;va_dcl
       switch(elt_type) {
       case aet_ch:
 	x = alloc_object(t_string);
+	x->ust.ust_adjustable=1;
 	goto a_string;
 	break;
       case aet_bit:
 	x = alloc_object(t_bitvector);
+	x->v.v_elttype = elt_type;
+	x->v.v_adjustable=1;
 	break;
       default:
 	x = alloc_object(t_vector);}
       x->v.v_elttype = elt_type;
+      x->v.v_adjustable=1;
     a_string:
       x->v.v_dim = n;
       x->v.v_self = 0;
@@ -414,7 +422,6 @@ int n;int elt_type;object staticp;va_dcl
     LA5: 
       displaced_index_offset= 0;
     LA6:
-      x->v.v_adjustable = 1;
       va_end(Iap);
       { if (displaced_to == Cnil)
 	  array_allocself(x,staticp!=Cnil,initial_element);
@@ -436,7 +443,7 @@ static short DFLT_aet_short = 0;
 static shortfloat DFLT_aet_sf = 0.0;
 static longfloat DFLT_aet_lf = 0.0;	
 static object Iname_t = sLt;
-struct { char * dflt; object *namep;} aet_types[] =
+static struct { char * dflt; object *namep;} aet_types[] =
 {   (char *)	&DFLT_aet_object,	&Iname_t,	/*  t  */
     (char *)	&DFLT_aet_ch, &sLstring_char,/*  string-char  */
     (char *)	&DFLT_aet_fix, &sLbit,		/*  bit  */
@@ -529,6 +536,8 @@ DEFUN("MAKE-ARRAY1",object,fSmake_array1,SI,6,6,
     v = dimensions;
     while (i < rank)
       { x->a.a_dims[i] = FIX_CHECK(Mcar(v));
+	if (x->a.a_dims[i] < 0)
+	  { FEerror("Dimension must be non negative",0);}
 	dim *= x->a.a_dims[i++];
 	v = Mcdr(v);}
     x->a.a_dim = dim;
@@ -588,9 +597,9 @@ displace(from_array,dest_array,offset)
   
     
   if (typ == aet_bit)
-    { offset += dest_array->bv.bv_offset;
+    { offset += BV_OFFSET(dest_array);
       from_array->bv.bv_self = dest_array->bv.bv_self + offset/BV_BITS;
-      from_array->bv.bv_offset = offset % BV_BITS;
+      SET_BV_OFFSET(from_array,offset % BV_BITS);
     }
   else
     from_array->a.a_self = ARRAY_BODY_PTR(dest_array,offset);
@@ -645,9 +654,9 @@ Idisplace_array(from,to,displaced_index_offset)
    DISPLACED_FROM(to) = make_cons(from,DISPLACED_FROM(to));
        
    if (t1 == aet_bit) {
-     displaced_index_offset += to->bv.bv_offset;
+     displaced_index_offset += BV_OFFSET(to);
      from->bv.bv_self = to->bv.bv_self + displaced_index_offset/BV_BITS;
-     from->bv.bv_offset = displaced_index_offset%BV_BITS;
+     SET_BV_OFFSET(from, displaced_index_offset%BV_BITS);
    }
    else
      from->st.st_self = ARRAY_BODY_PTR(to,displaced_index_offset);
@@ -761,7 +770,7 @@ implementation dependent results.")
   if (typ1==aet_bit)
     {if (i1 % CHAR_SIZE)
      badcopy:
-       FEerror("Bit copies only if aligned");
+       FEerror("Bit copies only if aligned",0);
     else
       {int rest=n1%CHAR_SIZE;
        if (rest!=0 )
@@ -781,11 +790,11 @@ implementation dependent results.")
        i2=i2/CHAR_SIZE ;}
   if ((typ1 ==aet_object ||
        typ2  ==aet_object) && typ1 != typ2)
-    FEerror("Can't copy between different array types");
+    FEerror("Can't copy between different array types",0);
   nc=n1 * aet_sizes[(int)typ1];
   if (i1+n1 > x->a.a_dim
       || ((y->a.a_dim - i2) *aet_sizes[(int)typ2]) < nc)
-    FEerror("Copy  out of bounds");
+    FEerror("Copy  out of bounds",0);
   bcopy(x->ust.ust_self + (i1*aet_sizes[(int)typ1]),
 	y->ust.ust_self + (i2*aet_sizes[(int)typ2]),
 	nc);
@@ -825,7 +834,7 @@ int staticp;
 		break;
 	case aet_bit:
 		n = (n+W_SIZE-1)/W_SIZE;
-		x->bv.bv_offset = 0;
+		SET_BV_OFFSET(x,0);
 	case aet_fix:
 		x->fixa.fixa_self = AR_ALLOC(*fun,n,fixnum);
 		break;
@@ -947,7 +956,9 @@ DEFUNO("ARRAY-DIMENSION",int,fLarray_dimension,LISP,2,2,
      object x; int i;
 { 
   if (type_of(x) == t_array)
-   {  if (i >= x->a.a_rank) FEerror("Index to large for array-dimension");
+   {  if ((unsigned int)i >= x->a.a_rank)
+	FEerror("Index ~a out of bounds for array-dimension",1
+		,make_fixnum(i));
       else { return x->a.a_dims[i];}}
    IisArray(x);
    return x->v.v_dim;
@@ -962,7 +973,7 @@ Icheck_displaced(displaced_list,ar,dim)
       if (u->a.a_self == NULL) continue;
       if ((Iarray_element_type(u) == aet_bit &&
 	   (u->bv.bv_self - ar->bv.bv_self)*BV_BITS +u->bv.bv_dim -dim
-	    + u->bv.bv_offset - ar->bv.bv_offset > 0)
+	    + BV_OFFSET(u) - BV_OFFSET(ar) > 0)
 	  || (ARRAY_BODY_PTR(u,u->a.a_dim) > ARRAY_BODY_PTR(ar,dim)))
 	FEerror("Bad displacement",0);
       Icheck_displaced(DISPLACED_FROM(u),ar,dim);
