@@ -39,7 +39,8 @@ object sSAindent_formatted_outputA;
 			VOL int old_fmt_end; \
 			jmp_bufp   VOL old_fmt_jmp_buf; \
 			VOL int old_fmt_indents; \
-			VOL object old_fmt_string
+			VOL object old_fmt_string ; \
+                        VOL format_parameter *old_fmt_paramp
 #define	fmt_save	old_fmt_stream = fmt_stream; \
 			old_ctl_origin = ctl_origin; \
 			old_ctl_index = ctl_index; \
@@ -49,7 +50,8 @@ object sSAindent_formatted_outputA;
 			old_fmt_end = fmt_end; \
 			old_fmt_jmp_buf = fmt_jmp_buf; \
 			old_fmt_indents = fmt_indents; \
-			old_fmt_string = fmt_string
+			old_fmt_string = fmt_string ; \
+                        old_fmt_paramp = fmt_paramp
 #define	fmt_restore	fmt_stream = old_fmt_stream; \
 			ctl_origin = old_ctl_origin; \
 			ctl_index = old_ctl_index; \
@@ -59,20 +61,24 @@ object sSAindent_formatted_outputA;
 			fmt_end = old_fmt_end; \
 			fmt_jmp_buf = old_fmt_jmp_buf; \
 			fmt_indents = old_fmt_indents; \
-			fmt_string = old_fmt_string
+			fmt_string = old_fmt_string ; \
+                        fmt_paramp = old_fmt_paramp 
+
 #define	fmt_restore1	fmt_stream = old_fmt_stream; \
 			ctl_origin = old_ctl_origin; \
 			ctl_index = old_ctl_index; \
 			ctl_end = old_ctl_end; \
 			fmt_jmp_buf = old_fmt_jmp_buf; \
 			fmt_indents = old_fmt_indents; \
-			fmt_string = old_fmt_string
+			fmt_string = old_fmt_string ; \
+                        fmt_paramp = old_fmt_paramp 
 
 typedef struct {
 	  int fmt_param_type;
 	  int fmt_param_value;
 	} format_parameter;
 
+format_parameter fmt_param[100];
 format_parameter *fmt_paramp;
 #define FMT_PARAM (fmt_paramp)
 
@@ -155,7 +161,6 @@ int ctl_end0;
 	int c, i, n;
 	bool colon, atsign;
 	object x;
-	format_parameter fmt_param[100];
 	fmt_paramp = fmt_param;
 
 	/* could eliminate the no interrupt if made the
@@ -240,9 +245,12 @@ LOOP:
 			break;
 
 		default:
-			if (n > 0)
+/*			if (n > 0)
 				fmt_error("illegal ,");
 			else
+*/
+            /* allow (FORMAT NIL "~5,,X" 10) ; ie ,just before directive */ 
+
 				goto DIRECTIVE;
 		}
 		n++;
@@ -708,7 +716,7 @@ fmt_integer(x, colon, atsign, radix, mincol, padchar, commachar)
 		PRINTbase = radix;
 		write_ch_fun = writec_PRINTstream;
 		write_object(x, 0);
-		cleanupPRINT();}
+		CLEANUP_PRINT_DEFAULT;}
 		l = fmt_temporary_string->st.st_fillp;
 		mincol -= l;
 		while (mincol-- > 0)
@@ -1627,7 +1635,7 @@ fmt_indirection(colon, atsign)
 		fmt_error("control string expected");
 	if (atsign) {
 		fmt_save;
-		fmt_jmp_buf = &fmt_jmp_buf0;
+		fmt_jmp_buf = fmt_jmp_buf0;
 		fmt_string = s;
 		if (up_colon = setjmp(*fmt_jmp_buf)) {
 			if (--up_colon)
@@ -1642,7 +1650,7 @@ fmt_indirection(colon, atsign)
 		fmt_index = 0;
 		for (fmt_end = 0;  !endp(l);  fmt_end++, l = l->c.c_cdr)
 			vs_check_push(l->c.c_car);
-		fmt_jmp_buf = &fmt_jmp_buf0;
+		fmt_jmp_buf = fmt_jmp_buf0;
 		fmt_string = s;
 		if (up_colon = setjmp(*fmt_jmp_buf)) {
 			if (--up_colon)
@@ -1671,7 +1679,7 @@ fmt_case(colon, atsign)
 	if (ctl_string[--j] != ')' || ctl_string[--j] != '~')
 		fmt_error("~) expected");
 	fmt_save;
-	fmt_jmp_buf = &fmt_jmp_buf0;
+	fmt_jmp_buf = fmt_jmp_buf0;
 	if (up_colon = setjmp(*fmt_jmp_buf))
 		;
 	else
@@ -1844,7 +1852,7 @@ fmt_iteration(colon, atsign)
 		fmt_index = 0;
 		for (fmt_end = 0;  !endp(l);  fmt_end++, l = l->c.c_cdr)
 			vs_check_push(l->c.c_car);
-		fmt_jmp_buf = &fmt_jmp_buf0;
+		fmt_jmp_buf = fmt_jmp_buf0;
 		if (colon_close)
 			goto L1;
 		while (fmt_index < fmt_end) {
@@ -1864,7 +1872,7 @@ fmt_iteration(colon, atsign)
 		l0 = fmt_advance();
 		fmt_save;
 		fmt_base = vs_top;
-		fmt_jmp_buf = &fmt_jmp_buf0;
+		fmt_jmp_buf = fmt_jmp_buf0;
 		if (colon_close)
 			goto L2;
 		while (!endp(l0)) {
@@ -1889,7 +1897,7 @@ fmt_iteration(colon, atsign)
 		fmt_restore;
 	} else if (!colon && atsign) {
 		fmt_save;
-		fmt_jmp_buf = &fmt_jmp_buf0;
+		fmt_jmp_buf = fmt_jmp_buf0;
 		if (colon_close)
 			goto L3;
 		while (fmt_index < fmt_end) {
@@ -1917,7 +1925,7 @@ fmt_iteration(colon, atsign)
 			fmt_index = 0;
 			for (fmt_end = 0; !endp(l); fmt_end++, l = l->c.c_cdr)
 				vs_check_push(l->c.c_car);
-			fmt_jmp_buf = &fmt_jmp_buf0;
+			fmt_jmp_buf = fmt_jmp_buf0;
 			if (up_colon = setjmp(*fmt_jmp_buf)) {
 				vs_top = fmt_base;
 				fmt_restore;
@@ -1966,7 +1974,7 @@ fmt_justification(colon, atsign)
 		fields[n] = make_string_output_stream(64);
 		vs_push(fields[n]);
 		fmt_save;
-		fmt_jmp_buf = &fmt_jmp_buf0;
+		fmt_jmp_buf = fmt_jmp_buf0;
 		if (up_colon = setjmp(*fmt_jmp_buf)) {
 			--n;
 			if (--up_colon)
@@ -2114,7 +2122,7 @@ DEFUNO("FORMAT",object,fLformat,LISP
 	fmt_base = l;
 	fmt_index = 0;
 	fmt_end = nargs;
-	fmt_jmp_buf = &fmt_jmp_buf0;
+	fmt_jmp_buf = fmt_jmp_buf0;
 	if (symbol_value(sSAindent_formatted_outputA) != Cnil)
 		fmt_indents = file_column(strm);
 	else
