@@ -630,7 +630,7 @@ int *bottom,*top;
     than 4 we need to mark twice
    */
 
- if (offset) {mark_stack_carefully(bottom,(((char *) top) +offset),0);}
+ if (offset) {mark_stack_carefully((((char *) top) +offset),bottom,0);}
  for (j=top ; j >= bottom ; j--)
    {if (VALID_DATA_ADDRESS_P(*j)
 	&& type_map[(p=page(*j))]< (char)t_end)
@@ -668,7 +668,7 @@ mark_phase()
 
 	mark_stack_carefully(vs_top-1,vs_org,0);
 	clear_stack(vs_top,vs_limit);
-	mark_stack_carefully(MVloc,MVloc+(sizeof(MVloc)/sizeof(object)),0);
+	mark_stack_carefully(MVloc+(sizeof(MVloc)/sizeof(object)),MVloc,0);
 	/* 
 	for (p = vs_org;  p < vs_top;  p++) {
 	  if (p && (inheap(*p)))
