@@ -342,7 +342,7 @@ double d;
 }
 
 object
-remainder(x, y, q)
+num_remainder(x, y, q)
 object x, y, q;
 {
 	object z;
@@ -530,7 +530,7 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -543,7 +543,7 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 	}
 }
@@ -651,7 +651,7 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -664,7 +664,7 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 	}
 }
@@ -738,7 +738,7 @@ TWO_ARG:
 		q1 = integer_divide1(q->rat.rat_num, q->rat.rat_den);
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -746,7 +746,7 @@ TWO_ARG:
 		q1 = double_to_integer(number_to_double(q));
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 	}
 }
@@ -855,7 +855,7 @@ TWO_ARG:
 			q1 = one_minus(q1);
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -876,7 +876,7 @@ TWO_ARG:
 		}
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 	}
 }
